# Reporting a vulnerability

To report a vulnerability, please contact us privately through the NuGet [Contact Owners](https://www.nuget.org/packages/Skender.Stock.Indicators) feature.  Please include a detailed description of the vulnerability.

We will inform everyone of vulnerability fixes in our release notes.
